==> v1.63.zip: wcs/wcs/ctl/wipe_data.py <==
# w.c.s. - web application for online forms
# Copyright (C) 2005-2016  Entr'ouvert
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, see <http://www.gnu.org/licenses/>.

import os
import sys

from qommon.ctl import Command, make_option

class CmdWipeData(Command):
    name = 'wipe-data'

    def __init__(self):
        Command.__init__(self, [
                make_option('--all', metavar='ALL', action='store_false',
                            dest='all'),
                make_option('--vhost', metavar='VHOST', action='store',
                            dest='vhost'),
                ])

    def execute(self, base_options, sub_options, args):
        if not sub_options.vhost:
            print >> sys.stderr, 'you must specify --vhost'
            sys.exit(1)

        import publisher
        publisher.WcsPublisher.configure(self.config)
        pub = publisher.WcsPublisher.create_publisher(
                register_cron=False, register_tld_names=False)
        pub.app_dir = os.path.join(pub.app_dir, sub_options.vhost)
        pub.set_config()
        self.wipe(pub, sub_options, args)

    def wipe(self, pub, options, args):
        from wcs.formdef import FormDef

        if options.all:
            formdefs = FormDef.select()
        elif args:
            formdefs = [FormDef.get_by_urlname(arg) for arg in args]
        else:
            formdefs = []

        for formdef in formdefs:
            formdef.data_class().wipe()

CmdWipeData.register()

==> v2.22.zip: wcs/wcs/ctl/wipe_data.py <==
# w.c.s. - web application for online forms
# Copyright (C) 2005-2016  Entr'ouvert
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, see <http://www.gnu.org/licenses/>.

import os
import sys

from qommon.ctl import Command, make_option

class CmdWipeData(Command):
    name = 'wipe-data'

    def __init__(self):
        Command.__init__(self, [
                make_option('--all', metavar='ALL', action='store_true',
                            dest='all'),
                make_option('--vhost', metavar='VHOST', action='store',
                            dest='vhost'),
                ])

    def execute(self, base_options, sub_options, args):
        if not sub_options.vhost:
            print >> sys.stderr, 'you must specify --vhost'
            sys.exit(1)

        import publisher
        publisher.WcsPublisher.configure(self.config)
        pub = publisher.WcsPublisher.create_publisher(
                register_tld_names=False)
        pub.app_dir = os.path.join(pub.app_dir, sub_options.vhost)
        pub.set_config()
        self.wipe(pub, sub_options, args)

    def wipe(self, pub, options, args):
        from wcs.formdef import FormDef

        if options.all:
            formdefs = FormDef.select()
        elif args:
            formdefs = [FormDef.get_by_urlname(arg) for arg in args]
        else:
            formdefs = []

        for formdef in formdefs:
            formdef.data_class().wipe()

CmdWipeData.register()
